Malt: Material for beer
=======================

Malt é um tema para o Pelican que tem como base o framework CSS `materialize`_ desenvolvido para ser utilizado no site do GrupyDF e está sendo adaptado para todos os outros Grupys interessados em utilizar.

.. image:: https://github.com/grupydf/malt/blob/master/screenshots/malt-home.png

Por quê Malt?
-------------

Por que no fim das contas um Grupy tem como objetivo juntar programadores Python para tomar cerveja, e um dos "materiais" da cerveja é o malte. É eu sei, trocadilho tosco. Mas eu não sou conhecido por fazer piadas boas, mas sim por programar bem :)

Funcionalidades
---------------

Para uma lista completa e detalhada das funcionalidade do tema leia a documentação de `Funcionalidades`_.

Licença
-------

.. code::

    Malt
    Copyright (C) 2015  Magnun Leno

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

.. _materialize: http://materializecss.com/
.. _Funcionalidades: https://github.com/grupydf/malt/blob/master/funcionalidades.rst
